pub struct CreateChannelInviteOptions {
pub max_uses: Option<u8>,
pub max_age: Option<Duration<Seconds>>,
pub unique: Option<bool>,
pub temporary: Option<bool>,
}Fields
max_uses: Option<u8>0-100, where 0 means unlimited.
max_age: Option<Duration<Seconds>>0-604800, duration until the invite expires where 0 means never.
unique: Option<bool>Whether to create a unique invite or reuse an existing one.
temporary: Option<bool>Whether members that joined via this invite should be kicked after disconnecting.
Implementations
Sourceimpl CreateChannelInviteOptions
impl CreateChannelInviteOptions
Sourcepub fn builder() -> CreateChannelInviteOptionsBuilder
pub fn builder() -> CreateChannelInviteOptionsBuilder
Create an instance of CreateChannelInviteOptions using the builder syntax