CreateChannelInviteOptionsBuilder

Struct CreateChannelInviteOptionsBuilder 

pub struct CreateChannelInviteOptionsBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> CreateChannelInviteOptionsBuilder<S>

pub fn build(self) -> CreateChannelInviteOptions
where S: IsComplete,

Finish building and return the requested object

pub fn max_uses( self, value: u8, ) -> CreateChannelInviteOptionsBuilder<SetMaxUses<S>>
where S::MaxUses: IsUnset,

Optional (Some / Option setters). 0-100, where 0 means unlimited.

pub fn maybe_max_uses( self, value: Option<u8>, ) -> CreateChannelInviteOptionsBuilder<SetMaxUses<S>>
where S::MaxUses: IsUnset,

Optional (Some / Option setters). 0-100, where 0 means unlimited.

pub fn max_age( self, value: Duration<Seconds>, ) -> CreateChannelInviteOptionsBuilder<SetMaxAge<S>>
where S::MaxAge: IsUnset,

Optional (Some / Option setters). 0-604800, duration until the invite expires where 0 means never.

pub fn maybe_max_age( self, value: Option<Duration<Seconds>>, ) -> CreateChannelInviteOptionsBuilder<SetMaxAge<S>>
where S::MaxAge: IsUnset,

Optional (Some / Option setters). 0-604800, duration until the invite expires where 0 means never.

pub fn unique( self, value: bool, ) -> CreateChannelInviteOptionsBuilder<SetUnique<S>>
where S::Unique: IsUnset,

Optional (Some / Option setters). Whether to create a unique invite or reuse an existing one.

pub fn maybe_unique( self, value: Option<bool>, ) -> CreateChannelInviteOptionsBuilder<SetUnique<S>>
where S::Unique: IsUnset,

Optional (Some / Option setters). Whether to create a unique invite or reuse an existing one.

pub fn temporary( self, value: bool, ) -> CreateChannelInviteOptionsBuilder<SetTemporary<S>>
where S::Temporary: IsUnset,

Optional (Some / Option setters). Whether members that joined via this invite should be kicked after disconnecting.

pub fn maybe_temporary( self, value: Option<bool>, ) -> CreateChannelInviteOptionsBuilder<SetTemporary<S>>
where S::Temporary: IsUnset,

Optional (Some / Option setters). Whether members that joined via this invite should be kicked after disconnecting.