ApiErrorCode

Enum ApiErrorCode 

pub enum ApiErrorCode {
Show 222 variants AccessDenied, AccountDisabled, AccountScheduledForDeletion, AccountSuspendedPermanently, AccountSuspendedTemporarily, AccountSuspiciousActivity, AccountTooNewForGuild, AclsMustBeNonEmpty, AdminApiKeyNotFound, AlreadyFriends, AuditLogIndexing, BotsCannotSendFriendRequests, BotUserAuthEndpointAccessDenied, BotUserAuthSessionCreationDenied, CallAlreadyExists, CannotEditOtherUserMessage, CannotExecuteOnDm, CannotModifySystemWebhook, CannotModifyVoiceState, CannotRedeemPlutoniumWithVisionary, CannotReportOwnGuild, CannotReportOwnMessage, CannotReportYourself, CannotSendEmptyMessage, CannotSendFriendRequestToBlockedUser, CannotSendFriendRequestToSelf, CannotSendMessagesInNonTextChannel, CannotSendMessagesToUser, CannotShrinkReservedSlots, CaptchaRequired, ChannelIndexing, CommunicationDisabled, ContentBlocked, CreationFailed, DeletionFailed, DiscriminatorRequired, EmailServiceNotTestable, EmailVerificationRequired, ExplicitContentCannotBeSent, FeatureTemporarilyDisabled, FileSizeTooLarge, FriendRequestBlocked, GeneralError, GiftCodeAlreadyRedeemed, GuildPhoneVerificationRequired, GuildVerificationRequired, HandoffCodeExpired, HarvestExpired, HarvestFailed, HarvestNotReady, HarvestOnCooldown, HttpGetAuthorizeNotSupported, InstanceVersionMismatch, InvalidAclsFormat, InvalidApiOrigin, InvalidAuthToken, InvalidBotFlag, InvalidCaptcha, InvalidChannelTypeForCall, InvalidChannelType, InvalidClient, InvalidClientSecret, InvalidDsaReportTarget, InvalidDsaTicket, InvalidDsaVerificationCode, InvalidFlagsFormat, InvalidFormBody, InvalidGrant, InvalidHandoffCode, InvalidPackType, InvalidPermissionsInteger, InvalidPermissionsNegative, InvalidPhoneNumber, InvalidPhoneVerificationCode, InvalidRedirectUri, InvalidRequest, InvalidResponseTypeForNonBot, InvalidScope, InvalidStreamKeyFormat, InvalidStreamThumbnailPayload, InvalidSudoToken, InvalidSuspiciousFlagsFormat, InvalidSystemFlag, InvalidTimestamp, InvalidToken, InvalidWebauthnAuthenticationCounter, InvalidWebauthnCredentialCounter, InvalidWebauthnCredential, InvalidWebauthnPublicKeyFormat, InvitesDisabled, IpAuthorizationRequired, IpAuthorizationResendCooldown, IpAuthorizationResendLimitExceeded, IpBanned, MaxAnimatedEmojis, MaxBetaCodesReached, MaxBookmarks, MaxCategoryChannels, MaxEmojis, MaxFavoriteMemes, MaxFriends, MaxGroupDmRecipients, MaxGroupDms, MaxGuildChannels, MaxGuildMembers, MaxGuildRoles, MaxGuilds, MaxInvites, MaxPackExpressions, MaxPacks, MaxPinsPerChannel, MaxReactions, MaxStickers, MaxWebhooksPerChannel, MaxWebhooksPerGuild, MaxWebhooks, NcmecAlreadySubmitted, NcmecSubmissionFailed, MediaMetadataError, MissingAccess, MissingAcl, MissingAuthorization, MissingClientSecret, MissingOauthAdminScope, MissingOauthFields, MissingOauthScope, MissingPermissions, MissingRedirectUri, NoActiveCall, NoActiveSubscription, NoPasskeysRegistered, NoPendingDeletion, NoUsersWithFluxertagExist, NoVisionarySlotsAvailable, NotFriendsWithUser, NotOwnerOfAdminApiKey, NsfwContentAgeRestricted, PackAccessDenied, PasskeyAuthenticationFailed, PasskeysDisabled, PhoneAlreadyUsed, PhoneRateLimitExceeded, PhoneRequiredForSmsMfa, PhoneVerificationRequired, PremiumPurchaseBlocked, PreviewMustBeJpeg, ProcessingFailed, RateLimited, RedirectUriRequiredForNonBot, ReportAlreadyResolved, ReportBanned, SessionTokenMismatch, SlowmodeRateLimited, SmsMfaNotEnabled, SmsMfaRequiresTotp, SmsVerificationUnavailable, SsoRequired, StreamKeyChannelMismatch, StreamKeyScopeMismatch, StreamThumbnailPayloadEmpty, StripeError, StripeGiftRedemptionInProgress, StripeInvalidProduct, StripeInvalidProductConfiguration, StripeNoActiveSubscription, StripeNoPurchaseHistory, StripeNoSubscription, StripePaymentNotAvailable, StripeSubscriptionAlreadyCanceling, StripeSubscriptionNotCanceling, StripeSubscriptionPeriodEndMissing, StripeWebhookNotAvailable, StripeWebhookSignatureInvalid, StripeWebhookSignatureMissing, SudoModeRequired, TagAlreadyTaken, TemporaryInviteRequiresPresence, TestHarnessDisabled, TestHarnessForbidden, TwoFaNotEnabled, TwoFactorRequired, Unauthorized, UnclaimedAccountCannotAcceptFriendRequests, UnclaimedAccountCannotAddReactions, UnclaimedAccountCannotCreateApplications, UnclaimedAccountCannotCreateBetaCodes, UnclaimedAccountCannotJoinGroupDms, UnclaimedAccountCannotJoinOneOnOneVoiceCalls, UnclaimedAccountCannotJoinVoiceChannels, UnclaimedAccountCannotMakePurchases, UnclaimedAccountCannotSendDirectMessages, UnclaimedAccountCannotSendFriendRequests, UnclaimedAccountCannotSendMessages, UnknownBetaCode, UnknownChannel, UnknownEmoji, UnknownFavoriteMeme, UnknownGiftCode, UnknownGuild, UnknownHarvest, UnknownInvite, UnknownMember, UnknownMessage, UnknownPack, UnknownReport, UnknownRole, UnknownSticker, UnknownSuspiciousFlag, UnknownUserFlag, UnknownUser, UnknownVoiceRegion, UnknownVoiceServer, UnknownWebauthnCredential, UnknownWebhook, UnsupportedResponseType, UpdateFailed, UserBannedFromGuild, UserIpBannedFromGuild, UserNotInVoice, UserOwnsGuilds, VoiceChannelFull, WebauthnCredentialLimitReached,
}

Variants



AccessDenied

Access to this resource is denied.



AccountDisabled

This account has been disabled.



AccountScheduledForDeletion

This account is scheduled for deletion.



AccountSuspendedPermanently

This account has been permanently suspended.



AccountSuspendedTemporarily

This account has been temporarily suspended.



AccountSuspiciousActivity

Suspicious activity detected on this account.



AccountTooNewForGuild

Account is too new to join this guild.



AclsMustBeNonEmpty

Access control list must not be empty.



AdminApiKeyNotFound

Admin API key was not found.



AlreadyFriends

You are already friends with this user.



AuditLogIndexing

Audit log is currently being indexed.



BotsCannotSendFriendRequests

Bots cannot send friend requests.



BotUserAuthEndpointAccessDenied

Bot users cannot access this authentication endpoint.



BotUserAuthSessionCreationDenied

Bot users cannot create authentication sessions.



CallAlreadyExists

A call already exists in this channel.



CannotEditOtherUserMessage

You cannot edit another user message.



CannotExecuteOnDm

This action cannot be executed on a DM channel.



CannotModifySystemWebhook

System webhooks cannot be modified.



CannotModifyVoiceState

Cannot modify voice state.



CannotRedeemPlutoniumWithVisionary

Cannot redeem plutonium while having Visionary subscription.



CannotReportOwnGuild

You cannot report your own guild.



CannotReportOwnMessage

You cannot report your own message.



CannotReportYourself

You cannot report yourself.



CannotSendEmptyMessage

Cannot send an empty message.



CannotSendFriendRequestToBlockedUser

Cannot send friend request to a blocked user.



CannotSendFriendRequestToSelf

Cannot send friend request to yourself.



CannotSendMessagesInNonTextChannel

Cannot send messages in a non-text channel.



CannotSendMessagesToUser

Cannot send messages to this user.



CannotShrinkReservedSlots

Cannot shrink reserved slots.



CaptchaRequired

Captcha verification is required.



ChannelIndexing

Channel is currently being indexed.



CommunicationDisabled

You are timed out in this guild.



ContentBlocked

Content was blocked.



CreationFailed

Resource creation failed.



DeletionFailed

Resource deletion failed.



DiscriminatorRequired

A discriminator is required.



EmailServiceNotTestable

Email service is not in testable mode.



EmailVerificationRequired

Email verification is required.



ExplicitContentCannotBeSent

Explicit content cannot be sent in this channel.



FeatureTemporarilyDisabled

This feature is temporarily disabled.



FileSizeTooLarge

File size exceeds the maximum allowed.



FriendRequestBlocked

Friend request was blocked.



GeneralError

A general error occurred.



GiftCodeAlreadyRedeemed

This gift code has already been redeemed.



GuildPhoneVerificationRequired

Phone verification is required to join this guild.



GuildVerificationRequired

Account verification is required to interact in this guild.



HandoffCodeExpired

Handoff code has expired.



HarvestExpired

Data harvest request has expired.



HarvestFailed

Data harvest failed.



HarvestNotReady

Data harvest is not yet ready.



HarvestOnCooldown

Data harvest is on cooldown.



HttpGetAuthorizeNotSupported

HTTP GET authorize is not supported.



InstanceVersionMismatch

Instance version mismatch.



InvalidAclsFormat

Invalid access control list format.



InvalidApiOrigin

Invalid API origin.



InvalidAuthToken

Invalid authentication token.



InvalidBotFlag

Invalid bot flag.



InvalidCaptcha

Invalid captcha response.



InvalidChannelTypeForCall

Invalid channel type for call.



InvalidChannelType

Invalid channel type.



InvalidClient

Invalid OAuth2 client.



InvalidClientSecret

Invalid client secret.



InvalidDsaReportTarget

Invalid DSA report target.



InvalidDsaTicket

Invalid DSA ticket.



InvalidDsaVerificationCode

Invalid DSA verification code.



InvalidFlagsFormat

Invalid flags format.



InvalidFormBody

Invalid request body format.



InvalidGrant

Invalid OAuth2 grant.



InvalidHandoffCode

Invalid handoff code.



InvalidPackType

Invalid pack type.



InvalidPermissionsInteger

Invalid permissions value.



InvalidPermissionsNegative

Permissions value cannot be negative.



InvalidPhoneNumber

Invalid phone number.



InvalidPhoneVerificationCode

Invalid phone verification code.



InvalidRedirectUri

Invalid redirect URI.



InvalidRequest

Invalid request.



InvalidResponseTypeForNonBot

Invalid response type for non-bot application.



InvalidScope

Invalid OAuth2 scope.



InvalidStreamKeyFormat

Invalid stream key format.



InvalidStreamThumbnailPayload

Invalid stream thumbnail payload.



InvalidSudoToken

Invalid sudo token.



InvalidSuspiciousFlagsFormat

Invalid suspicious flags format.



InvalidSystemFlag

Invalid system flag.



InvalidTimestamp

Invalid timestamp.



InvalidToken

Invalid token.



InvalidWebauthnAuthenticationCounter

Invalid WebAuthn authentication counter.



InvalidWebauthnCredentialCounter

Invalid WebAuthn credential counter.



InvalidWebauthnCredential

Invalid WebAuthn credential.



InvalidWebauthnPublicKeyFormat

Invalid WebAuthn public key format.



InvitesDisabled

Invites are disabled for this guild.



IpAuthorizationRequired

IP address authorization is required.



IpAuthorizationResendCooldown

IP authorization email resend is on cooldown.



IpAuthorizationResendLimitExceeded

IP authorization email resend limit exceeded.



IpBanned

This IP address has been banned.



MaxAnimatedEmojis

Maximum animated emojis limit reached.



MaxBetaCodesReached

Maximum beta codes limit reached.



MaxBookmarks

Maximum bookmarks limit reached.



MaxCategoryChannels

Maximum category channels limit reached.



MaxEmojis

Maximum emojis limit reached.



MaxFavoriteMemes

Maximum favourite memes limit reached.



MaxFriends

Maximum friends limit reached.



MaxGroupDmRecipients

Maximum group DM recipients limit reached.



MaxGroupDms

Maximum group DMs limit reached.



MaxGuildChannels

Maximum guild channels limit reached.



MaxGuildMembers

Maximum guild members limit reached.



MaxGuildRoles

Maximum guild roles limit reached.



MaxGuilds

Maximum guilds limit reached.



MaxInvites

Maximum invites limit reached.



MaxPackExpressions

Maximum pack expressions limit reached.



MaxPacks

Maximum packs limit reached.



MaxPinsPerChannel

Maximum pins per channel limit reached.



MaxReactions

Maximum reactions limit reached.



MaxStickers

Maximum stickers limit reached.



MaxWebhooksPerChannel

Maximum webhooks per channel limit reached.



MaxWebhooksPerGuild

Maximum webhooks per guild limit reached.



MaxWebhooks

Maximum webhooks limit reached.



NcmecAlreadySubmitted

NCMEC report has already been submitted.



NcmecSubmissionFailed

NCMEC report submission failed.



MediaMetadataError

Error processing media metadata.



MissingAccess

Missing access to this resource.



MissingAcl

Missing access control list entry.



MissingAuthorization

Missing authorization header.



MissingClientSecret

Missing client secret.



MissingOauthAdminScope

Missing OAuth admin scope.



MissingOauthFields

Missing required OAuth fields.



MissingOauthScope

Missing required OAuth scope.



MissingPermissions

Missing required permissions.



MissingRedirectUri

Missing redirect URI.



NoActiveCall

No active call in this channel.



NoActiveSubscription

No active subscription.



NoPasskeysRegistered

No passkeys registered for this account.



NoPendingDeletion

No pending deletion for this account.



NoUsersWithFluxertagExist

No users with this Fluxertag exist.



NoVisionarySlotsAvailable

No Visionary slots available.



NotFriendsWithUser

You are not friends with this user.



NotOwnerOfAdminApiKey

You are not the owner of this admin API key.



NsfwContentAgeRestricted

NSFW content is age restricted.



PackAccessDenied

Access to this pack is denied.



PasskeyAuthenticationFailed

Passkey authentication failed.



PasskeysDisabled

Passkeys are disabled.



PhoneAlreadyUsed

This phone number is already in use.



PhoneRateLimitExceeded

Phone verification rate limit exceeded.



PhoneRequiredForSmsMfa

Phone number required for SMS MFA.



PhoneVerificationRequired

Phone verification is required.



PremiumPurchaseBlocked

Premium purchase is blocked.



PreviewMustBeJpeg

Preview image must be JPEG format.



ProcessingFailed

Processing failed.



RateLimited

You are being rate limited.



RedirectUriRequiredForNonBot

Redirect URI required for non-bot application.



ReportAlreadyResolved

This report has already been resolved.



ReportBanned

You are banned from submitting reports.



SessionTokenMismatch

Session token mismatch.



SlowmodeRateLimited

You are being rate limited by slowmode.



SmsMfaNotEnabled

SMS MFA is not enabled.



SmsMfaRequiresTotp

SMS MFA requires TOTP to be enabled first.



SmsVerificationUnavailable

SMS verification is unavailable.



SsoRequired

Single sign-on is required.



StreamKeyChannelMismatch

Stream key does not match channel.



StreamKeyScopeMismatch

Stream key scope mismatch.



StreamThumbnailPayloadEmpty

Stream thumbnail payload is empty.



StripeError

Stripe payment error.



StripeGiftRedemptionInProgress

Gift redemption already in progress.



StripeInvalidProduct

Invalid Stripe product.



StripeInvalidProductConfiguration

Invalid Stripe product configuration.



StripeNoActiveSubscription

No active Stripe subscription.



StripeNoPurchaseHistory

No Stripe purchase history.



StripeNoSubscription

No Stripe subscription.



StripePaymentNotAvailable

Stripe payment not available.



StripeSubscriptionAlreadyCanceling

Subscription is already being cancelled.



StripeSubscriptionNotCanceling

Subscription is not being cancelled.



StripeSubscriptionPeriodEndMissing

Subscription period end date is missing.



StripeWebhookNotAvailable

Stripe webhook not available.



StripeWebhookSignatureInvalid

Invalid Stripe webhook signature.



StripeWebhookSignatureMissing

Missing Stripe webhook signature.



SudoModeRequired

Sudo mode is required for this action.



TagAlreadyTaken

This tag is already taken.



TemporaryInviteRequiresPresence

Temporary invite requires presence tracking.



TestHarnessDisabled

Test harness is disabled.



TestHarnessForbidden

Test harness access is forbidden.



TwoFaNotEnabled

Two-factor authentication is not enabled.



TwoFactorRequired

Two-factor authentication is required.



Unauthorized

Unauthorized.



UnclaimedAccountCannotAcceptFriendRequests

Unclaimed accounts cannot accept friend requests.



UnclaimedAccountCannotAddReactions

Unclaimed accounts cannot add reactions.



UnclaimedAccountCannotCreateApplications

Unclaimed accounts cannot create applications.



UnclaimedAccountCannotCreateBetaCodes

Unclaimed accounts cannot create beta codes.



UnclaimedAccountCannotJoinGroupDms

Unclaimed accounts cannot join group DMs.



UnclaimedAccountCannotJoinOneOnOneVoiceCalls

Unclaimed accounts cannot join one-on-one voice calls.



UnclaimedAccountCannotJoinVoiceChannels

Unclaimed accounts cannot join voice channels.



UnclaimedAccountCannotMakePurchases

Unclaimed accounts cannot make purchases.



UnclaimedAccountCannotSendDirectMessages

Unclaimed accounts cannot send direct messages.



UnclaimedAccountCannotSendFriendRequests

Unclaimed accounts cannot send friend requests.



UnclaimedAccountCannotSendMessages

Unclaimed accounts cannot send messages.



UnknownBetaCode

Unknown beta code.



UnknownChannel

Unknown channel.



UnknownEmoji

Unknown emoji.



UnknownFavoriteMeme

Unknown favourite meme.



UnknownGiftCode

Unknown gift code.



UnknownGuild

Unknown guild.



UnknownHarvest

Unknown data harvest.



UnknownInvite

Unknown invite.



UnknownMember

Unknown member.



UnknownMessage

Unknown message.



UnknownPack

Unknown pack.



UnknownReport

Unknown report.



UnknownRole

Unknown role.



UnknownSticker

Unknown sticker.



UnknownSuspiciousFlag

Unknown suspicious flag.



UnknownUserFlag

Unknown user flag.



UnknownUser

Unknown user.



UnknownVoiceRegion

Unknown voice region.



UnknownVoiceServer

Unknown voice server.



UnknownWebauthnCredential

Unknown WebAuthn credential.



UnknownWebhook

Unknown webhook.



UnsupportedResponseType

Unsupported response type.



UpdateFailed

Resource update failed.



UserBannedFromGuild

User is banned from this guild.



UserIpBannedFromGuild

User IP is banned from this guild.



UserNotInVoice

User is not in a voice channel.



UserOwnsGuilds

User owns guilds and cannot perform this action.



VoiceChannelFull

Voice channel is full.



WebauthnCredentialLimitReached

WebAuthn credential limit reached.