pub struct Request {
pub body: Option<String>,
pub headers: Option<HeaderMap<HeaderValue>>,
pub method: Method,
pub path: String,
pub use_authorization_token: bool,
pub params: Option<HashMap<String, String>>,
}Fields
body: Option<String>headers: Option<HeaderMap<HeaderValue>>method: Methodpath: Stringparams: Option<HashMap<String, String>>Implementations
Sourceimpl Request
impl Request
Sourcepub fn builder() -> RequestBuilder
pub fn builder() -> RequestBuilder
Create an instance of Request using the builder syntax
Sourceimpl Request
impl Request
Sourcepub async fn execute(self, client: &HttpClient) -> Result<Response, Error>
pub async fn execute(self, client: &HttpClient) -> Result<Response, Error>
Execute the request. For a non-consuming version, see Self::borrowed_execute.
Errors
Returns an error if there was an error while sending the request, a redirect loop was detected or the redirect limit was exhausted.
Sourcepub async fn borrowed_execute(
&self,
client: &HttpClient,
) -> Result<Response, Error>
pub async fn borrowed_execute( &self, client: &HttpClient, ) -> Result<Response, Error>
Execute the request without consuming it. This clones certain fields when necessary. For a consuming version, see Self::execute.
Errors
Returns the same errors as Self::execute.